# -*- coding: utf-8; mode: python -*-
"""
Rattail core data model extensions
"""

from __future__ import unicode_literals, absolute_import

import sqlalchemy as sa
from sqlalchemy import orm

from rattail.db import model
from rattail.db.core import uuid_column


class Rattail_tutorialCustomer(model.Base):
    """
    Rattail Tutorial extensions to core Customer model
    """
    __tablename__ = 'rattail_tutorial_customer'
    __table_args__ = (
        sa.ForeignKeyConstraint(['uuid'], ['customer.uuid'], name='rattail_tutorial_customer_fk_customer'),
    )

    uuid = uuid_column(default=None)

    customer = orm.relationship(
        model.Customer,
        doc="""
        Customer to which this extension record pertains.
        """,
        backref=orm.backref(
            '_rattail_tutorial',
            uselist=False,
            cascade='all, delete-orphan',
            doc="""
            Rattail Tutorial-specific extension record for the customer.
            """),
    )

    mail_list_synced = sa.Column(sa.Boolean(), nullable=False, default=False, doc="""
    Flag indicating whether the customer's email address has been synced to the
    general mailing list.
    """)
